################
webcolors-stubs
################

`PEP 561`_ based Type information for webcolors_.

.. _PEP 561: https://www.python.org/dev/peps/pep-0561
.. _webcolors: https://github.com/ubernostrum/webcolors

``webcolors`` is a module for working with HTML/CSS color definitions.


.. start shields 

.. list-table::
	:stub-columns: 1
	:widths: 10 90

	* - Tests
	  - |travis| |requires| |coveralls| |codefactor|
	* - PyPI
	  - |pypi-version| |supported-versions| |supported-implementations| |wheel|
	* - Other
	  - |license| |language| |commits-since| |commits-latest| |maintained| 



.. |travis| image:: https://img.shields.io/travis/com/domdfcoding/webcolors-stubs/master?logo=travis
	:target: https://travis-ci.com/domdfcoding/webcolors-stubs
	:alt: Travis Build Status

.. |requires| image:: https://requires.io/github/domdfcoding/webcolors-stubs/requirements.svg?branch=master
	:target: https://requires.io/github/domdfcoding/webcolors-stubs/requirements/?branch=master
	:alt: Requirements Status

.. |coveralls| image:: https://img.shields.io/coveralls/github/domdfcoding/webcolors-stubs/master?logo=coveralls
	:target: https://coveralls.io/github/domdfcoding/webcolors-stubs?branch=master
	:alt: Coverage

.. |codefactor| image:: https://img.shields.io/codefactor/grade/github/domdfcoding/webcolors-stubs?logo=codefactor
	:target: https://www.codefactor.io/repository/github/domdfcoding/webcolors-stubs
	:alt: CodeFactor Grade

.. |pypi-version| image:: https://img.shields.io/pypi/v/webcolors-stubs
	:target: https://pypi.org/project/webcolors-stubs/
	:alt: PyPI - Package Version

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/webcolors-stubs
	:target: https://pypi.org/project/webcolors-stubs/
	:alt: PyPI - Supported Python Versions

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/webcolors-stubs
	:target: https://pypi.org/project/webcolors-stubs/
	:alt: PyPI - Supported Implementations

.. |wheel| image:: https://img.shields.io/pypi/wheel/webcolors-stubs
	:target: https://pypi.org/project/webcolors-stubs/
	:alt: PyPI - Wheel

.. |license| image:: https://img.shields.io/github/license/domdfcoding/webcolors-stubs
	:alt: License
	:target: https://github.com/domdfcoding/webcolors-stubs/blob/master/LICENSE

.. |language| image:: https://img.shields.io/github/languages/top/domdfcoding/webcolors-stubs
	:alt: GitHub top language

.. |commits-since| image:: https://img.shields.io/github/commits-since/domdfcoding/webcolors-stubs/v0.0.3
	:target: https://github.com/domdfcoding/webcolors-stubs/pulse
	:alt: GitHub commits since tagged version

.. |commits-latest| image:: https://img.shields.io/github/last-commit/domdfcoding/webcolors-stubs
	:target: https://github.com/domdfcoding/webcolors-stubs/commit/master
	:alt: GitHub last commit

.. |maintained| image:: https://img.shields.io/maintenance/yes/2020
	:alt: Maintenance

.. end shields

Full documentation for ``webcolors`` is `available online <https://webcolors.readthedocs.io/>`_.

|

Installation
--------------

.. start installation

``webcolors-stubs`` can be installed from PyPI.

To install with ``pip``:

.. code-block:: bash

	$ python -m pip install webcolors-stubs

.. end installation
